@@ -1,20 +1,24 @@
 from typing import List
 import requests
 
-# from magicapi import settings
 from magicapi import g
 
 
 def send_email(text: str, recipients: List[str], subject: str = ""):
+    data = {
+        "from": f"{g.settings.mailgun_sender_name} <{g.settings.mailgun_sender_email}>",
+        "to": recipients,
+        "subject": subject,
+        "text": text,
+    }
+    if "html" in data["text"]:
+        data["html"] = data["text"]
+        del data["text"]
+
     return requests.post(
         f"https://api.mailgun.net/v3/{g.settings.mailgun_domain_name}/messages",
         auth=("api", g.settings.mailgun_private_api_key),
-        data={
-            "from": f"{g.settings.mailgun_sender_name} <{g.settings.mailgun_sender_email}>",
-            "to": recipients,
-            "subject": subject,
-            "text": text,
-        },
+        data=data,
     )
 
 
